@@ -5,7 +5,7 @@
 #'
 #' @param formula a symbolic description of the systematic component of the model to be fitted. See details for further information.
 #' @param data an optional data frame, list containing the variables in the model.
-#' @param shape an optional value for the shape parameter of the error distribution of a generalized log-gamma distribution. Default value is 1.
+#' @param shape an optional value for the shape parameter of the error distribution of a generalized log-gamma distribution. Default value is 0.2.
 #' @param Tolerance an optional positive value, which represents the convergence criterion. Default value is 1e-04.
 #' @param Maxiter an optional positive integer giving the maximal number of iterations for the estimating process. Default value is 1e03.
 #' @param format an optional string value that indicates if you want a simple or a complete report of the estimating process. Default value is 'complete'.
@@ -18,13 +18,12 @@
 #' @return Deviance the deviance associated with the model.
 
 #' @references Carlos Alberto Cardozo Delgado, Semi-parametric generalized log-gamma regression models. Ph. D. thesis. Sao Paulo University.
-#' @author Carlos Alberto Cardozo Delgado <cardozorpackages@gmail.com>, G. Paula and L. Vanegas.
+#' @author Carlos Alberto Cardozo Delgado <cardozorpackages@gmail.com>
 #' @examples
 #' set.seed(21)
-#' rows <- 200
-#' columns <- 2
+#' rows <- 120
 #' x1 <- rbinom(rows, 1, 0.5)
-#' x2 <- runif(columns, 0, 1)
+#' x2 <- runif(rows, 0, 1)
 #' X <- cbind(x1,x2)
 #' t_beta  <- c(0.5, 2)
 #' t_sigma <- 1
@@ -35,12 +34,12 @@
 #' #                    #
 #' ######################
 #'
-#' t_lambda <- 1
+#' t_lambda <- 1 # 1 -0.9
 #' error <- rglg(rows, 0, 1, t_lambda)
 #' y1 <- X %*%t_beta + t_sigma * error
 #' data.example <- data.frame(y1,X)
-#' fit <- glg(y1 ~ x1 + x2 - 1,data=data.example)
-#' logLik(fit)
+#' fit <- glg(y1 ~ x1 + x2 - 1,data=data.example) # (-0.9,6.1) and (1,5.6)
+#' logLik(fit) # -180.598 and -183.907
 #' summary(fit)
 #' deviance_residuals(fit)
 #' #############################
@@ -48,10 +47,11 @@
 #' # Normal case: A limit case #
 #' #                           #
 #' #############################
-#'
+#' # When the parameter lambda goes to zero the GLG tends to a standard normal distribution.
 #' t_lambda <- 0.001
 #' set.seed(8142031)
 #' error <- rglg(rows, 0, 1, t_lambda)
+#' hist(error)
 #' y1 <- X %*%t_beta + t_sigma * error
 #' data.example <- data.frame(y1, X)
 #' fit0 <- glg(y1 ~ x1 + x2 - 1,data=data.example)
@@ -70,9 +70,10 @@
 #' AIC(fit2)
 #' coefficients(fit2)
 #' @import methods
+#' @importFrom Rcpp sourceCpp
 #' @export glg
 
-glg = function(formula, data, shape, Tolerance, Maxiter, format, envelope= FALSE) {
+glg = function(formula, data, shape=0.2, Tolerance=5e-05, Maxiter=1000, format, envelope= FALSE) {
     if (missingArg(formula)) {
         stop("The formula argument is missing.")
     }
@@ -80,12 +81,6 @@ glg = function(formula, data, shape, Tolerance, Maxiter, format, envelope= FALSE
         stop("The data argument is missing.")
     }
 
-    if (missingArg(Tolerance))
-        Tolerance <- 1e-04
-    if (missingArg(Maxiter))
-        Maxiter <- 1000
-    if (missingArg(shape))
-        shape <- 1
     if (missingArg(format))
         format <- 'complete'
     if (class(data) == "list")
@@ -100,9 +95,9 @@ glg = function(formula, data, shape, Tolerance, Maxiter, format, envelope= FALSE
 
     # Initial values
 
-    fit0 <- lm(formula, data = data)
-    beta0 <- coefficients(fit0)
-    sigma0 <- sum(fit0$residuals^2)/fit0$df.residual
+    fit0 <- .lm.fit(X,y)
+    beta0 <- coef(fit0)
+    sigma0 <- sum(fit0$residuals^2)/(n-p)
     lambda0 <- shape
 
     # Some fixed matrizes
@@ -113,139 +108,111 @@ glg = function(formula, data, shape, Tolerance, Maxiter, format, envelope= FALSE
 
     t_X <- t(X)
     I_11 <- function(sigm) {
-        output <- (1/(sigm^2)) * t_X %*% X
-        return(output)
+        return((1/(sigm^2)) * t_X %*% X)
     }
 
     t_XOne <- t_X %*% One
     I_12 <- function(sigm, lambd) {
-        output <- (1/(sigm^2)) * u_lambda(lambd) * t_XOne
-        return(output)
+        return((1/(sigm^2)) * u_lambda(lambd) * t_XOne)
     }
 
     I_13 <- function(sigm, lambd) {
-        output <- (-1/(sigm * lambd)) * u_lambda(lambd) * t_XOne
-        return(output)
+        return((-1/(sigm * lambd)) * u_lambda(lambd) * t_XOne)
     }
 
     I_33 <- function(sigm, lambd) {
-        output <- (n/(lambd^2)) * K_1(lambd)
-        return(output)
+        return((n/(lambd^2)) * K_1(lambd))
     }
 
     I_theta <- function(sigm,lambd) {
         output <- matrix(0, p + 2, p + 2)
-        output[1:p, 1:p] = I_11(sigm)
-        output[1:p, (p + 1)] = I_12(sigm,lambd)
-        output[1:p, (p + 2)] = I_13(sigm,lambd)
-        output[(p + 1), 1:p] = t(output[1:p, (p + 1)])
-        output[(p + 1), (p + 1)] = I_22(n,sigm,lambd)
-        output[(p + 1), (p + 2)] = I_23(n,sigm,lambd)
-        output[(p + 2), 1:p] = t(I_13(sigm,lambd))
-        output[(p + 2), (p + 1)] = t(I_23(n,sigm,lambd))
-        output[(p + 2), (p + 2)] = I_33(sigm,lambd)
+        output[1:p,] = cbind(I_11(sigm),I_12(sigm,lambd),I_13(sigm,lambd))
+        output[(p + 1),] = c(output[1:p, (p + 1)],I_22(n,sigm,lambd),I_23(n,sigm,lambd))
+        output[(p + 2),] = c(I_13(sigm,lambd),I_23(n,sigm,lambd),I_33(sigm,lambd))
         return(output)
     }
 
-    # SCORE FUNCTIONS
-
-    ## Weight matrix for the score functions
-
     ### Defining mu function
 
     mu <- function(bet) {
-        output <- X %*% bet
-        return(output)
+        return(X %*% bet)
     }
 
     ### First step: The residuals
 
     eps <- function(bet, sigm) {
-        epsilon <- (y - mu(bet))/sigm
-        return(epsilon)
+        return( (y - mu(bet))/sigm)
     }
 
     ### Second step: The matrix D
 
     D <- function(epsilon, lambd) {
-        D_eps <- diag(as.vector(exp(lambd * epsilon)))
-        return(D_eps)
+        return(diag(as.vector(exp(lambd * epsilon))))
     }
 
     ### Third step: The matrix W
 
     W <- function(bet, sigm, lambd) {
-        output <- I - D(eps(bet, sigm), lambd)
-        return(output)
+        return(I - D(eps(bet, sigm), lambd))
     }
 
     ## Final step: Score functions
 
     U_beta <- function(bet, sigm, lambd) {
-        output <- (-1/(lambd * sigm)) * t_X %*% W(bet, sigm, lambd) %*%One
-        return(output)
+        return((-1/(lambd * sigm)) * t_X %*% W(bet, sigm, lambd) %*%One)
     }
 
     t_One <- t(One)
     U_sigma <- function(bet, sigm, lambd) {
-        output <- -(1/sigm) * n - (1/(lambd * sigm)) * t_One %*% W(bet,sigm, lambd) %*% eps(bet, sigm)
-        return(output)
+        return(-(1/sigm) * n - (1/(lambd * sigm)) * t_One %*% W(bet,sigm, lambd) %*% eps(bet, sigm))
     }
 
     U_lambda <- function(bet, sigm, lambd) {
         invlamb <- 1/lambd
-        eta_lambd <- (invlamb) * (1 + 2 * (invlamb^2) * (digamma(invlamb^2) + 2 * log(abs(lambd)) - 1))
+        invlamb2 <- invlamb^2
+        eta_lambd <- (invlamb) * (1 + 2 * (invlamb2) * (digamma(invlamb2) + 2 * log(abs(lambd)) - 1))
         Ds <- D(eps(bet, sigm), lambd)
         epsilons <- eps(bet, sigm)
         t_OneDs <- t_One %*% Ds
-        output <- n * eta_lambd - (invlamb^2) * t_One %*% epsilons + (2 * invlamb^3) * t_OneDs %*% One - (invlamb^2) * t_OneDs %*% epsilons
-        return(output)
+        return(n * eta_lambd - (invlamb2) * t_One %*% epsilons + (2 * invlamb*invlamb2) * t_OneDs %*% One - (invlamb2) * t_OneDs %*% epsilons)
     }
 
     U_theta <- function(bet, sigm, lambd) {
-        output <- matrix(1, p + 2, 1)
-        output[1:p] <- U_beta(bet, sigm, lambd)
-        output[p + 1] <- U_sigma(bet, sigm, lambd)
-        output[p + 2] <- U_lambda(bet, sigm, lambd)
-        return(output)
+        return(c(U_beta(bet, sigm, lambd),U_sigma(bet, sigm, lambd),U_lambda(bet, sigm, lambd)))
     }
 
     ## LOG-LIKELIHOOD
 
     loglikglg <- function(bet, sigm, lambd) {
         epsilon <- eps(bet, sigm)
-        output <- n * log(c_l(lambd)/sigm) + (1/lambd) * t_One %*% epsilon - (1/lambd^2) * t_One %*% D(epsilon, lambd) %*% One
-        return(output)
+        invlamb <- 1/lambd
+        return(n * log(c_l(lambd)/sigm) + (invlamb) * t_One %*% epsilon - (invlamb^2) * t_One %*% D(epsilon, lambd) %*% One)
     }
 
     ## THE ESTIMATES
 
     newpar <- function(bet, sigm, lambd) {
         output <- matrix(0, p + 2, 2)
-        output[1:p, 1] <- bet
-        output[p + 1, 1] <- sigm
-        output[p + 2, 1] <- lambd
+        output[, 1] <- c(bet,sigm,lambd)
         new <- output[, 1]
-        output[, 2] <- output[, 1] + solve(I_theta(sigm, lambd)) %*% U_theta(bet,
-            sigm, lambd)
+        output[, 2] <- output[, 1] + solve(I_theta(sigm, lambd)) %*% U_theta(bet, sigm, lambd)
         M = 2
         while (output[p + 1, 2] < 0 & M < Maxiter) {
-            output[, 2] = 0.99 * output[, 2] + 0.01 * output[, 1]
+            output[, 2] = 0.8 * output[, 2] + 0.2 * output[, 1]
             M = M + 1
         }
         llglg = loglikglg(output[1:p, 2], output[p + 1, 2], output[p + 2,
-            2])
+                                                                   2])
         condition = llglg - loglikglg(output[1:p, 1], output[p + 1, 1], output[p +
-            2, 1])
+                                                                                   2, 1])
         if (condition > 0) {
             new = output[, 2]
         }
         M = 2
         while (condition < 0 & M < Maxiter) {
-            output[, 2] = 0.99 * output[, 2] + 0.01 * output[, 1]
-            condition = loglikglg(output[1:p, 2], output[p + 1, 2], output[p +
-                2, 2]) - loglikglg(output[1:p, 1], output[p + 1, 1], output[p +
-                2, 1])
+            output[, 2] = 0.8 * output[, 2] + 0.2 * output[, 1]
+            condition = loglikglg(output[1:p, 2], output[p + 1, 2], output[p + 2, 2]) - loglikglg(output[1:p, 1], output[p + 1, 1], output[p +
+                                                                                                                                               2, 1])
             if (condition > 0) {
                 new = output[, 2]
             }
@@ -297,7 +264,7 @@ glg = function(formula, data, shape, Tolerance, Maxiter, format, envelope= FALSE
 
     output <- optimum(beta0, sigma0, lambda0)
 
-    if (abs(output$est[p + 2]) < 0.09) {
+    if (abs(output$est[p + 2]) < 0.2) {
         output <- optimum(beta0, sigma0, -lambda0)
     }
 
@@ -332,7 +299,6 @@ glg = function(formula, data, shape, Tolerance, Maxiter, format, envelope= FALSE
         aic <- -2 * llglg + 2 * (p + 2)
         bic <- -2 * llglg + log(n) * (p + 2)
         aic2 <- aic + 2 * sum(y)
-        covar <- matrix(0, p + 2, p + 2)
         covar <- I_theta(output[p + 1], output[p + 2])
         ste <- sqrt(diag(solve(covar)))
         zs <- output/ste
@@ -346,15 +312,12 @@ glg = function(formula, data, shape, Tolerance, Maxiter, format, envelope= FALSE
             2])^2) - log((1/output[p + 2])^2))
         y_est <- mu_est + part2
         scores <- U_theta(output[1:p], output[p + 1], output[p + 2])
-        inter <- matrix(0, p + 2, 2)
-        inter[, 1] <- as.matrix(output - 1.96 * ste)
-        inter[, 2] <- as.matrix(output + 1.96 * ste)
-        good_fit <- gfit(ordresidual, output[p + 2])
+        inter <- cbind(output - 1.96 * ste, output + 1.96 * ste)
         output <- list(formula = formula, size = n, mu = output[1:p], sigma = output[p +
             1], lambda = output[p + 2], y = y, p = p, X = X, Knot = 0, llglg = llglg,
             scores = scores, AIC = aic, BIC = bic, AIC2 = aic2, deviance = devian,
             rdev = dev, Itheta = covar, st_error = ste, z_values = zs, p.values = pval,
-            interval = inter, goodnessoffit = good_fit, convergence = conv,
+            interval = inter, convergence = conv,
             condition = condition, iterations = iter, mu_est = mu_est, y_est = y_est, rord = ordresidual,
             semi = FALSE, censored = FALSE)
         class(output) = "sglg"
